@@ -1,33 +1,10 @@
-HLfit <-
-function (model = NULL, obs = NULL, pred = NULL, bin.method, n.bins = 10, fixed.bin.size = FALSE, min.bin.size = 15, min.prob.interval = 0.1, quantile.type = 7, simplif = FALSE, verbosity = 2, alpha = 0.05, plot = TRUE, plot.values = TRUE, plot.bin.size = TRUE, xlab = "Predicted probability", ylab = "Observed prevalence", ...) {
-  # version 2.0 (26 Nov 2021)
-
-  if (!is.null(model)) {
-    #if(!("glm" %in% class(model) && model$family$family == "binomial" && model$family$link == "logit")) stop ("'model' must be an object of class 'glm' with 'binomial' family and 'logit' link.")
-    if (!is.null(obs)) message("Argument 'obs' ignored in favour of 'model'.")
-    if (!is.null(pred)) message("Argument 'pred' ignored in favour of 'model'.")
-    # obs <- model$y
-    # pred <- model$fitted.values
-    obspred <- mod2obspred(model)
-    obs <- obspred[ , "obs"]
-    pred <- obspred[ , "pred"]
-    
-  } else {  # if is.null model
-    
-    if (is.null(obs) | is.null(pred)) stop ("You must provide either the 'obs'
-and 'pred' vectors, or a 'model' object.")
-    if (length(obs) != length(pred))  stop ("'obs' and 'pred' must have the same number of values (and in the same order).")
-    
-    # new (15 Sep 2015):
-    dat <- data.frame(obs, pred)
-    n.in <- nrow(dat)
-    dat <- na.omit(dat)
-    n.out <- nrow(dat)
-    if (n.out < n.in)  warning (n.in - n.out, " observations removed due to missing data; ", n.out, " observations actually evaluated.")
-    obs <- dat$obs
-    pred <- dat$pred
-  }  # end if is.null model
+HLfit <- function (model = NULL, obs = NULL, pred = NULL, bin.method, n.bins = 10, fixed.bin.size = FALSE, min.bin.size = 15, min.prob.interval = 0.1, quantile.type = 7, simplif = FALSE, verbosity = 2, alpha = 0.05, plot = TRUE, plot.values = TRUE, plot.bin.size = TRUE, xlab = "Predicted probability", ylab = "Observed prevalence", na.rm = TRUE, rm.dup = FALSE, ...) {
+  # version 2.1 (6 May 2022)
 
+  obspred <- inputMunch(model, obs, pred, na.rm = na.rm, rm.dup = rm.dup)  
+  obs <- obspred[ , "obs"]
+  pred <- obspred[ , "pred"]
+  
   stopifnot(
     length(obs) == length(pred),
     obs %in% c(0, 1)#,
